Class CommandsOuterClass.CreateAndExerciseCommand

java.lang.Object
com.google.protobuf.AbstractMessageLite
com.google.protobuf.AbstractMessage
com.google.protobuf.GeneratedMessageV3
com.daml.ledger.api.v2.CommandsOuterClass.CreateAndExerciseCommand
All Implemented Interfaces:
CommandsOuterClass.CreateAndExerciseCommandOrBuilder, com.google.protobuf.Message, com.google.protobuf.MessageLite, com.google.protobuf.MessageLiteOrBuilder, com.google.protobuf.MessageOrBuilder, Serializable
Enclosing class:
CommandsOuterClass

public static final class CommandsOuterClass.CreateAndExerciseCommand extends com.google.protobuf.GeneratedMessageV3 implements CommandsOuterClass.CreateAndExerciseCommandOrBuilder
 Create a contract and exercise a choice on it in the same transaction.
 
Protobuf type com.daml.ledger.api.v2.CreateAndExerciseCommand
See Also:
  • Field Details

    • TEMPLATE_ID_FIELD_NUMBER

      public static final int TEMPLATE_ID_FIELD_NUMBER
      See Also:
    • CREATE_ARGUMENTS_FIELD_NUMBER

      public static final int CREATE_ARGUMENTS_FIELD_NUMBER
      See Also:
    • CHOICE_FIELD_NUMBER

      public static final int CHOICE_FIELD_NUMBER
      See Also:
    • CHOICE_ARGUMENT_FIELD_NUMBER

      public static final int CHOICE_ARGUMENT_FIELD_NUMBER
      See Also:
  • Method Details

    • newInstance

      protected Object newInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused)
      Overrides:
      newInstance in class com.google.protobuf.GeneratedMessageV3
    • getDescriptor

      public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
    • internalGetFieldAccessorTable

      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable internalGetFieldAccessorTable()
      Specified by:
      internalGetFieldAccessorTable in class com.google.protobuf.GeneratedMessageV3
    • hasTemplateId

      public boolean hasTemplateId()
       The template of the contract the client wants to create.
       Both package-name and package-id reference identifier formats for the template-id are supported.
       Note: The package-id reference identifier format is deprecated. We plan to end support for this format in version 3.4.
      
       Required
       
      .com.daml.ledger.api.v2.Identifier template_id = 1;
      Specified by:
      hasTemplateId in interface CommandsOuterClass.CreateAndExerciseCommandOrBuilder
      Returns:
      Whether the templateId field is set.
    • getTemplateId

      public com.daml.ledger.api.v2.ValueOuterClass.Identifier getTemplateId()
       The template of the contract the client wants to create.
       Both package-name and package-id reference identifier formats for the template-id are supported.
       Note: The package-id reference identifier format is deprecated. We plan to end support for this format in version 3.4.
      
       Required
       
      .com.daml.ledger.api.v2.Identifier template_id = 1;
      Specified by:
      getTemplateId in interface CommandsOuterClass.CreateAndExerciseCommandOrBuilder
      Returns:
      The templateId.
    • getTemplateIdOrBuilder

      public com.daml.ledger.api.v2.ValueOuterClass.IdentifierOrBuilder getTemplateIdOrBuilder()
       The template of the contract the client wants to create.
       Both package-name and package-id reference identifier formats for the template-id are supported.
       Note: The package-id reference identifier format is deprecated. We plan to end support for this format in version 3.4.
      
       Required
       
      .com.daml.ledger.api.v2.Identifier template_id = 1;
      Specified by:
      getTemplateIdOrBuilder in interface CommandsOuterClass.CreateAndExerciseCommandOrBuilder
    • hasCreateArguments

      public boolean hasCreateArguments()
       The arguments required for creating a contract from this template.
      
       Required
       
      .com.daml.ledger.api.v2.Record create_arguments = 2;
      Specified by:
      hasCreateArguments in interface CommandsOuterClass.CreateAndExerciseCommandOrBuilder
      Returns:
      Whether the createArguments field is set.
    • getCreateArguments

      public com.daml.ledger.api.v2.ValueOuterClass.Record getCreateArguments()
       The arguments required for creating a contract from this template.
      
       Required
       
      .com.daml.ledger.api.v2.Record create_arguments = 2;
      Specified by:
      getCreateArguments in interface CommandsOuterClass.CreateAndExerciseCommandOrBuilder
      Returns:
      The createArguments.
    • getCreateArgumentsOrBuilder

      public com.daml.ledger.api.v2.ValueOuterClass.RecordOrBuilder getCreateArgumentsOrBuilder()
       The arguments required for creating a contract from this template.
      
       Required
       
      .com.daml.ledger.api.v2.Record create_arguments = 2;
      Specified by:
      getCreateArgumentsOrBuilder in interface CommandsOuterClass.CreateAndExerciseCommandOrBuilder
    • getChoice

      public String getChoice()
       The name of the choice the client wants to exercise.
       Must be a valid NameString (as described in ``value.proto``).
      
       Required
       
      string choice = 3;
      Specified by:
      getChoice in interface CommandsOuterClass.CreateAndExerciseCommandOrBuilder
      Returns:
      The choice.
    • getChoiceBytes

      public com.google.protobuf.ByteString getChoiceBytes()
       The name of the choice the client wants to exercise.
       Must be a valid NameString (as described in ``value.proto``).
      
       Required
       
      string choice = 3;
      Specified by:
      getChoiceBytes in interface CommandsOuterClass.CreateAndExerciseCommandOrBuilder
      Returns:
      The bytes for choice.
    • hasChoiceArgument

      public boolean hasChoiceArgument()
       The argument for this choice.
      
       Required
       
      .com.daml.ledger.api.v2.Value choice_argument = 4;
      Specified by:
      hasChoiceArgument in interface CommandsOuterClass.CreateAndExerciseCommandOrBuilder
      Returns:
      Whether the choiceArgument field is set.
    • getChoiceArgument

      public com.daml.ledger.api.v2.ValueOuterClass.Value getChoiceArgument()
       The argument for this choice.
      
       Required
       
      .com.daml.ledger.api.v2.Value choice_argument = 4;
      Specified by:
      getChoiceArgument in interface CommandsOuterClass.CreateAndExerciseCommandOrBuilder
      Returns:
      The choiceArgument.
    • getChoiceArgumentOrBuilder

      public com.daml.ledger.api.v2.ValueOuterClass.ValueOrBuilder getChoiceArgumentOrBuilder()
       The argument for this choice.
      
       Required
       
      .com.daml.ledger.api.v2.Value choice_argument = 4;
      Specified by:
      getChoiceArgumentOrBuilder in interface CommandsOuterClass.CreateAndExerciseCommandOrBuilder
    • isInitialized

      public final boolean isInitialized()
      Specified by:
      isInitialized in interface com.google.protobuf.MessageLiteOrBuilder
      Overrides:
      isInitialized in class com.google.protobuf.GeneratedMessageV3
    • writeTo

      public void writeTo(com.google.protobuf.CodedOutputStream output) throws IOException
      Specified by:
      writeTo in interface com.google.protobuf.MessageLite
      Overrides:
      writeTo in class com.google.protobuf.GeneratedMessageV3
      Throws:
      IOException
    • getSerializedSize

      public int getSerializedSize()
      Specified by:
      getSerializedSize in interface com.google.protobuf.MessageLite
      Overrides:
      getSerializedSize in class com.google.protobuf.GeneratedMessageV3
    • equals

      public boolean equals(Object obj)
      Specified by:
      equals in interface com.google.protobuf.Message
      Overrides:
      equals in class com.google.protobuf.AbstractMessage
    • hashCode

      public int hashCode()
      Specified by:
      hashCode in interface com.google.protobuf.Message
      Overrides:
      hashCode in class com.google.protobuf.AbstractMessage
    • parseFrom

      public static CommandsOuterClass.CreateAndExerciseCommand parseFrom(ByteBuffer data) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static CommandsOuterClass.CreateAndExerciseCommand parseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static CommandsOuterClass.CreateAndExerciseCommand parseFrom(com.google.protobuf.ByteString data) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static CommandsOuterClass.CreateAndExerciseCommand parseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static CommandsOuterClass.CreateAndExerciseCommand parseFrom(byte[] data) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static CommandsOuterClass.CreateAndExerciseCommand parseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      Throws:
      IOException
    • parseFrom

      public static CommandsOuterClass.CreateAndExerciseCommand parseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
      Throws:
      IOException
    • parseDelimitedFrom

      public static CommandsOuterClass.CreateAndExerciseCommand parseDelimitedFrom(InputStream input) throws IOException
      Throws:
      IOException
    • parseDelimitedFrom

      public static CommandsOuterClass.CreateAndExerciseCommand parseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
      Throws:
      IOException
    • parseFrom

      public static CommandsOuterClass.CreateAndExerciseCommand parseFrom(com.google.protobuf.CodedInputStream input) throws IOException
      Throws:
      IOException
    • parseFrom

      public static CommandsOuterClass.CreateAndExerciseCommand parseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
      Throws:
      IOException
    • newBuilderForType

      Specified by:
      newBuilderForType in interface com.google.protobuf.Message
      Specified by:
      newBuilderForType in interface com.google.protobuf.MessageLite
    • newBuilder

    • newBuilder

    • toBuilder

      Specified by:
      toBuilder in interface com.google.protobuf.Message
      Specified by:
      toBuilder in interface com.google.protobuf.MessageLite
    • newBuilderForType

      protected CommandsOuterClass.CreateAndExerciseCommand.Builder newBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent)
      Specified by:
      newBuilderForType in class com.google.protobuf.GeneratedMessageV3
    • getDefaultInstance

      public static CommandsOuterClass.CreateAndExerciseCommand getDefaultInstance()
    • parser

      public static com.google.protobuf.Parser<CommandsOuterClass.CreateAndExerciseCommand> parser()
    • getParserForType

      public com.google.protobuf.Parser<CommandsOuterClass.CreateAndExerciseCommand> getParserForType()
      Specified by:
      getParserForType in interface com.google.protobuf.Message
      Specified by:
      getParserForType in interface com.google.protobuf.MessageLite
      Overrides:
      getParserForType in class com.google.protobuf.GeneratedMessageV3
    • getDefaultInstanceForType

      public CommandsOuterClass.CreateAndExerciseCommand getDefaultInstanceForType()
      Specified by:
      getDefaultInstanceForType in interface com.google.protobuf.MessageLiteOrBuilder
      Specified by:
      getDefaultInstanceForType in interface com.google.protobuf.MessageOrBuilder