Class CommandsOuterClass.PrefetchContractKey

java.lang.Object
com.google.protobuf.AbstractMessageLite
com.google.protobuf.AbstractMessage
com.google.protobuf.GeneratedMessageV3
com.daml.ledger.api.v2.CommandsOuterClass.PrefetchContractKey
All Implemented Interfaces:
CommandsOuterClass.PrefetchContractKeyOrBuilder, com.google.protobuf.Message, com.google.protobuf.MessageLite, com.google.protobuf.MessageLiteOrBuilder, com.google.protobuf.MessageOrBuilder, Serializable
Enclosing class:
CommandsOuterClass

public static final class CommandsOuterClass.PrefetchContractKey extends com.google.protobuf.GeneratedMessageV3 implements CommandsOuterClass.PrefetchContractKeyOrBuilder
 Preload contracts
 
Protobuf type com.daml.ledger.api.v2.PrefetchContractKey
See Also:
  • Field Details

    • TEMPLATE_ID_FIELD_NUMBER

      public static final int TEMPLATE_ID_FIELD_NUMBER
      See Also:
    • CONTRACT_KEY_FIELD_NUMBER

      public static final int CONTRACT_KEY_FIELD_NUMBER
      See Also:
    • LIMIT_FIELD_NUMBER

      public static final int LIMIT_FIELD_NUMBER
      See Also:
  • Method Details

    • newInstance

      protected Object newInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused)
      Overrides:
      newInstance in class com.google.protobuf.GeneratedMessageV3
    • getDescriptor

      public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
    • internalGetFieldAccessorTable

      protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable internalGetFieldAccessorTable()
      Specified by:
      internalGetFieldAccessorTable in class com.google.protobuf.GeneratedMessageV3
    • hasTemplateId

      public boolean hasTemplateId()
       The template of contract the client wants to prefetch.
       Both package-name and package-id reference identifier formats for the template-id are supported.
       Note: The package-id reference identifier format is deprecated. We plan to end support for this format in version 3.4.
      
       Required
       
      .com.daml.ledger.api.v2.Identifier template_id = 1;
      Specified by:
      hasTemplateId in interface CommandsOuterClass.PrefetchContractKeyOrBuilder
      Returns:
      Whether the templateId field is set.
    • getTemplateId

      public com.daml.ledger.api.v2.ValueOuterClass.Identifier getTemplateId()
       The template of contract the client wants to prefetch.
       Both package-name and package-id reference identifier formats for the template-id are supported.
       Note: The package-id reference identifier format is deprecated. We plan to end support for this format in version 3.4.
      
       Required
       
      .com.daml.ledger.api.v2.Identifier template_id = 1;
      Specified by:
      getTemplateId in interface CommandsOuterClass.PrefetchContractKeyOrBuilder
      Returns:
      The templateId.
    • getTemplateIdOrBuilder

      public com.daml.ledger.api.v2.ValueOuterClass.IdentifierOrBuilder getTemplateIdOrBuilder()
       The template of contract the client wants to prefetch.
       Both package-name and package-id reference identifier formats for the template-id are supported.
       Note: The package-id reference identifier format is deprecated. We plan to end support for this format in version 3.4.
      
       Required
       
      .com.daml.ledger.api.v2.Identifier template_id = 1;
      Specified by:
      getTemplateIdOrBuilder in interface CommandsOuterClass.PrefetchContractKeyOrBuilder
    • hasContractKey

      public boolean hasContractKey()
       The key of the contract the client wants to prefetch.
      
       Required
       
      .com.daml.ledger.api.v2.Value contract_key = 2;
      Specified by:
      hasContractKey in interface CommandsOuterClass.PrefetchContractKeyOrBuilder
      Returns:
      Whether the contractKey field is set.
    • getContractKey

      public com.daml.ledger.api.v2.ValueOuterClass.Value getContractKey()
       The key of the contract the client wants to prefetch.
      
       Required
       
      .com.daml.ledger.api.v2.Value contract_key = 2;
      Specified by:
      getContractKey in interface CommandsOuterClass.PrefetchContractKeyOrBuilder
      Returns:
      The contractKey.
    • getContractKeyOrBuilder

      public com.daml.ledger.api.v2.ValueOuterClass.ValueOrBuilder getContractKeyOrBuilder()
       The key of the contract the client wants to prefetch.
      
       Required
       
      .com.daml.ledger.api.v2.Value contract_key = 2;
      Specified by:
      getContractKeyOrBuilder in interface CommandsOuterClass.PrefetchContractKeyOrBuilder
    • hasLimit

      public boolean hasLimit()
       The number of contracts to prefetch for this key, if available.
       This is in addition to disclosed contracts.
       - for backward compatibility reason, absence is interpreted as 1
       - 0 is forbidden
       - capped at 2^31 - 1. The system may impose further limits.
      
       Optional
       
      optional uint32 limit = 3;
      Specified by:
      hasLimit in interface CommandsOuterClass.PrefetchContractKeyOrBuilder
      Returns:
      Whether the limit field is set.
    • getLimit

      public int getLimit()
       The number of contracts to prefetch for this key, if available.
       This is in addition to disclosed contracts.
       - for backward compatibility reason, absence is interpreted as 1
       - 0 is forbidden
       - capped at 2^31 - 1. The system may impose further limits.
      
       Optional
       
      optional uint32 limit = 3;
      Specified by:
      getLimit in interface CommandsOuterClass.PrefetchContractKeyOrBuilder
      Returns:
      The limit.
    • isInitialized

      public final boolean isInitialized()
      Specified by:
      isInitialized in interface com.google.protobuf.MessageLiteOrBuilder
      Overrides:
      isInitialized in class com.google.protobuf.GeneratedMessageV3
    • writeTo

      public void writeTo(com.google.protobuf.CodedOutputStream output) throws IOException
      Specified by:
      writeTo in interface com.google.protobuf.MessageLite
      Overrides:
      writeTo in class com.google.protobuf.GeneratedMessageV3
      Throws:
      IOException
    • getSerializedSize

      public int getSerializedSize()
      Specified by:
      getSerializedSize in interface com.google.protobuf.MessageLite
      Overrides:
      getSerializedSize in class com.google.protobuf.GeneratedMessageV3
    • equals

      public boolean equals(Object obj)
      Specified by:
      equals in interface com.google.protobuf.Message
      Overrides:
      equals in class com.google.protobuf.AbstractMessage
    • hashCode

      public int hashCode()
      Specified by:
      hashCode in interface com.google.protobuf.Message
      Overrides:
      hashCode in class com.google.protobuf.AbstractMessage
    • parseFrom

      public static CommandsOuterClass.PrefetchContractKey parseFrom(ByteBuffer data) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static CommandsOuterClass.PrefetchContractKey parseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static CommandsOuterClass.PrefetchContractKey parseFrom(com.google.protobuf.ByteString data) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static CommandsOuterClass.PrefetchContractKey parseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static CommandsOuterClass.PrefetchContractKey parseFrom(byte[] data) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static CommandsOuterClass.PrefetchContractKey parseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
      Throws:
      com.google.protobuf.InvalidProtocolBufferException
    • parseFrom

      public static CommandsOuterClass.PrefetchContractKey parseFrom(InputStream input) throws IOException
      Throws:
      IOException
    • parseFrom

      public static CommandsOuterClass.PrefetchContractKey parseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
      Throws:
      IOException
    • parseDelimitedFrom

      public static CommandsOuterClass.PrefetchContractKey parseDelimitedFrom(InputStream input) throws IOException
      Throws:
      IOException
    • parseDelimitedFrom

      public static CommandsOuterClass.PrefetchContractKey parseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
      Throws:
      IOException
    • parseFrom

      public static CommandsOuterClass.PrefetchContractKey parseFrom(com.google.protobuf.CodedInputStream input) throws IOException
      Throws:
      IOException
    • parseFrom

      public static CommandsOuterClass.PrefetchContractKey parseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
      Throws:
      IOException
    • newBuilderForType

      Specified by:
      newBuilderForType in interface com.google.protobuf.Message
      Specified by:
      newBuilderForType in interface com.google.protobuf.MessageLite
    • newBuilder

    • newBuilder

    • toBuilder

      Specified by:
      toBuilder in interface com.google.protobuf.Message
      Specified by:
      toBuilder in interface com.google.protobuf.MessageLite
    • newBuilderForType

      protected CommandsOuterClass.PrefetchContractKey.Builder newBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent)
      Specified by:
      newBuilderForType in class com.google.protobuf.GeneratedMessageV3
    • getDefaultInstance

      public static CommandsOuterClass.PrefetchContractKey getDefaultInstance()
    • parser

      public static com.google.protobuf.Parser<CommandsOuterClass.PrefetchContractKey> parser()
    • getParserForType

      public com.google.protobuf.Parser<CommandsOuterClass.PrefetchContractKey> getParserForType()
      Specified by:
      getParserForType in interface com.google.protobuf.Message
      Specified by:
      getParserForType in interface com.google.protobuf.MessageLite
      Overrides:
      getParserForType in class com.google.protobuf.GeneratedMessageV3
    • getDefaultInstanceForType

      public CommandsOuterClass.PrefetchContractKey getDefaultInstanceForType()
      Specified by:
      getDefaultInstanceForType in interface com.google.protobuf.MessageLiteOrBuilder
      Specified by:
      getDefaultInstanceForType in interface com.google.protobuf.MessageOrBuilder