Enum Class CryptoOuterClass.CryptoKeyFormat

java.lang.Object
java.lang.Enum<CryptoOuterClass.CryptoKeyFormat>
com.daml.ledger.api.v2.CryptoOuterClass.CryptoKeyFormat
All Implemented Interfaces:
com.google.protobuf.Internal.EnumLite, com.google.protobuf.ProtocolMessageEnum, Serializable, Comparable<CryptoOuterClass.CryptoKeyFormat>, Constable
Enclosing class:
CryptoOuterClass

public static enum CryptoOuterClass.CryptoKeyFormat extends Enum<CryptoOuterClass.CryptoKeyFormat> implements com.google.protobuf.ProtocolMessageEnum
 Serialization format for crypto keys and signatures
 
Protobuf enum com.daml.ledger.api.v2.CryptoKeyFormat
  • Enum Constant Details

    • CRYPTO_KEY_FORMAT_UNSPECIFIED

      public static final CryptoOuterClass.CryptoKeyFormat CRYPTO_KEY_FORMAT_UNSPECIFIED
      CRYPTO_KEY_FORMAT_UNSPECIFIED = 0;
    • CRYPTO_KEY_FORMAT_DER

      public static final CryptoOuterClass.CryptoKeyFormat CRYPTO_KEY_FORMAT_DER
       ASN.1 + DER encoding
       Legacy format no longer used, except for migrations
       
      CRYPTO_KEY_FORMAT_DER = 1;
    • CRYPTO_KEY_FORMAT_RAW

      public static final CryptoOuterClass.CryptoKeyFormat CRYPTO_KEY_FORMAT_RAW
       Raw encoding of a key
       
      CRYPTO_KEY_FORMAT_RAW = 2;
    • CRYPTO_KEY_FORMAT_DER_X509_SUBJECT_PUBLIC_KEY_INFO

      public static final CryptoOuterClass.CryptoKeyFormat CRYPTO_KEY_FORMAT_DER_X509_SUBJECT_PUBLIC_KEY_INFO
       ASN.1 + DER-encoding of X.509 SubjectPublicKeyInfo structure: https://datatracker.ietf.org/doc/html/rfc5280#section-4.1
       
      CRYPTO_KEY_FORMAT_DER_X509_SUBJECT_PUBLIC_KEY_INFO = 3;
    • UNRECOGNIZED

      public static final CryptoOuterClass.CryptoKeyFormat UNRECOGNIZED
  • Field Details

    • CRYPTO_KEY_FORMAT_UNSPECIFIED_VALUE

      public static final int CRYPTO_KEY_FORMAT_UNSPECIFIED_VALUE
      CRYPTO_KEY_FORMAT_UNSPECIFIED = 0;
      See Also:
    • CRYPTO_KEY_FORMAT_DER_VALUE

      public static final int CRYPTO_KEY_FORMAT_DER_VALUE
       ASN.1 + DER encoding
       Legacy format no longer used, except for migrations
       
      CRYPTO_KEY_FORMAT_DER = 1;
      See Also:
    • CRYPTO_KEY_FORMAT_RAW_VALUE

      public static final int CRYPTO_KEY_FORMAT_RAW_VALUE
       Raw encoding of a key
       
      CRYPTO_KEY_FORMAT_RAW = 2;
      See Also:
    • CRYPTO_KEY_FORMAT_DER_X509_SUBJECT_PUBLIC_KEY_INFO_VALUE

      public static final int CRYPTO_KEY_FORMAT_DER_X509_SUBJECT_PUBLIC_KEY_INFO_VALUE
       ASN.1 + DER-encoding of X.509 SubjectPublicKeyInfo structure: https://datatracker.ietf.org/doc/html/rfc5280#section-4.1
       
      CRYPTO_KEY_FORMAT_DER_X509_SUBJECT_PUBLIC_KEY_INFO = 3;
      See Also:
  • Method Details

    • values

      public static CryptoOuterClass.CryptoKeyFormat[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static CryptoOuterClass.CryptoKeyFormat valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null
    • getNumber

      public final int getNumber()
      Specified by:
      getNumber in interface com.google.protobuf.Internal.EnumLite
      Specified by:
      getNumber in interface com.google.protobuf.ProtocolMessageEnum
    • valueOf

      @Deprecated public static CryptoOuterClass.CryptoKeyFormat valueOf(int value)
      Deprecated.
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      value - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null
    • forNumber

      public static CryptoOuterClass.CryptoKeyFormat forNumber(int value)
      Parameters:
      value - The numeric wire value of the corresponding enum entry.
      Returns:
      The enum associated with the given numeric wire value.
    • internalGetValueMap

      public static com.google.protobuf.Internal.EnumLiteMap<CryptoOuterClass.CryptoKeyFormat> internalGetValueMap()
    • getValueDescriptor

      public final com.google.protobuf.Descriptors.EnumValueDescriptor getValueDescriptor()
      Specified by:
      getValueDescriptor in interface com.google.protobuf.ProtocolMessageEnum
    • getDescriptorForType

      public final com.google.protobuf.Descriptors.EnumDescriptor getDescriptorForType()
      Specified by:
      getDescriptorForType in interface com.google.protobuf.ProtocolMessageEnum
    • getDescriptor

      public static final com.google.protobuf.Descriptors.EnumDescriptor getDescriptor()
    • valueOf

      public static CryptoOuterClass.CryptoKeyFormat valueOf(com.google.protobuf.Descriptors.EnumValueDescriptor desc)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      desc - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null