Package com.daml.ledger.api.v2.admin
Class CommandInspectionServiceOuterClass.CommandStatus
java.lang.Object
com.google.protobuf.AbstractMessageLite
com.google.protobuf.AbstractMessage
com.google.protobuf.GeneratedMessageV3
com.daml.ledger.api.v2.admin.CommandInspectionServiceOuterClass.CommandStatus
- All Implemented Interfaces:
CommandInspectionServiceOuterClass.CommandStatusOrBuilder,com.google.protobuf.Message,com.google.protobuf.MessageLite,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,Serializable
- Enclosing class:
CommandInspectionServiceOuterClass
public static final class CommandInspectionServiceOuterClass.CommandStatus
extends com.google.protobuf.GeneratedMessageV3
implements CommandInspectionServiceOuterClass.CommandStatusOrBuilder
Protobuf type
com.daml.ledger.api.v2.admin.CommandStatus- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic final classProtobuf typecom.daml.ledger.api.v2.admin.CommandStatusNested classes/interfaces inherited from class com.google.protobuf.GeneratedMessageV3
com.google.protobuf.GeneratedMessageV3.BuilderParent, com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>,BuilderT extends com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageT, BuilderT>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessageOrBuilder<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessageV3.FieldAccessorTable, com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter Nested classes/interfaces inherited from class com.google.protobuf.AbstractMessageLite
com.google.protobuf.AbstractMessageLite.InternalOneOfEnum -
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final intstatic final intstatic final intstatic final intstatic final intstatic final intstatic final intstatic final intstatic final intFields inherited from class com.google.protobuf.GeneratedMessageV3
alwaysUseFieldBuilders, unknownFieldsFields inherited from class com.google.protobuf.AbstractMessage
memoizedSizeFields inherited from class com.google.protobuf.AbstractMessageLite
memoizedHashCode -
Method Summary
Modifier and TypeMethodDescriptionbooleangetCommands(int index) The individual submitted commands Required: must be non-emptyintThe individual submitted commands Required: must be non-emptyThe individual submitted commands Required: must be non-emptygetCommandsOrBuilder(int index) The individual submitted commands Required: must be non-emptyList<? extends CommandsOuterClass.CommandOrBuilder> The individual submitted commands Required: must be non-emptycom.google.protobuf.TimestampTime at which the command was completed.com.google.protobuf.TimestampOrBuilderTime at which the command was completed.The completion associated with the command Contains only default values if the command is still pending OptionalThe completion associated with the command Contains only default values if the command is still pending Optionalstatic final com.google.protobuf.Descriptors.Descriptorcom.google.protobuf.Parser<CommandInspectionServiceOuterClass.CommandStatus> Statistics about the command request OptionalStatistics about the command request Optionalintcom.google.protobuf.TimestampTime at which the command was received for interpretation by the participant.com.google.protobuf.TimestampOrBuilderTime at which the command was received for interpretation by the participant.getState()The state of the command RequiredintThe state of the command RequiredSynchronizer-ID.com.google.protobuf.ByteStringSynchronizer-ID.getTimings(int index) Timings for the individual stages Optional: can be emptyintTimings for the individual stages Optional: can be emptyTimings for the individual stages Optional: can be emptygetTimingsOrBuilder(int index) Timings for the individual stages Optional: can be emptyTimings for the individual stages Optional: can be emptyThe ledger updates effected by the command OptionalThe ledger updates effected by the command OptionalbooleanTime at which the command was completed.booleanThe completion associated with the command Contains only default values if the command is still pending OptionalinthashCode()booleanStatistics about the command request OptionalbooleanTime at which the command was received for interpretation by the participant.booleanThe ledger updates effected by the command Optionalprotected com.google.protobuf.GeneratedMessageV3.FieldAccessorTablefinal booleannewBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent) protected ObjectnewInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused) parseDelimitedFrom(InputStream input) parseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) parseFrom(byte[] data) parseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) parseFrom(com.google.protobuf.ByteString data) parseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) parseFrom(com.google.protobuf.CodedInputStream input) parseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) parseFrom(InputStream input) parseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) parseFrom(ByteBuffer data) parseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) static com.google.protobuf.Parser<CommandInspectionServiceOuterClass.CommandStatus> parser()voidwriteTo(com.google.protobuf.CodedOutputStream output) Methods inherited from class com.google.protobuf.GeneratedMessageV3
canUseUnsafe, computeStringSize, computeStringSizeNoTag, emptyBooleanList, emptyDoubleList, emptyFloatList, emptyIntList, emptyList, emptyLongList, getAllFields, getDescriptorForType, getField, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, getUnknownFields, hasField, hasOneof, internalGetMapField, internalGetMapFieldReflection, isStringEmpty, makeExtensionsImmutable, makeMutableCopy, makeMutableCopy, mergeFromAndMakeImmutableInternal, mutableCopy, mutableCopy, mutableCopy, mutableCopy, mutableCopy, newBooleanList, newBuilderForType, newDoubleList, newFloatList, newIntList, newLongList, parseDelimitedWithIOException, parseDelimitedWithIOException, parseUnknownField, parseUnknownFieldProto3, parseWithIOException, parseWithIOException, parseWithIOException, parseWithIOException, serializeBooleanMapTo, serializeIntegerMapTo, serializeLongMapTo, serializeStringMapTo, writeReplace, writeString, writeStringNoTagMethods inherited from class com.google.protobuf.AbstractMessage
findInitializationErrors, getInitializationErrorString, hashBoolean, hashEnum, hashEnumList, hashFields, hashLong, toStringMethods inherited from class com.google.protobuf.AbstractMessageLite
addAll, addAll, checkByteStringIsUtf8, toByteArray, toByteString, writeDelimitedTo, writeToMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface com.google.protobuf.MessageLite
toByteArray, toByteString, writeDelimitedTo, writeToMethods inherited from interface com.google.protobuf.MessageOrBuilder
findInitializationErrors, getAllFields, getDescriptorForType, getField, getInitializationErrorString, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, getUnknownFields, hasField, hasOneof
-
Field Details
-
STARTED_FIELD_NUMBER
public static final int STARTED_FIELD_NUMBER- See Also:
-
COMPLETED_FIELD_NUMBER
public static final int COMPLETED_FIELD_NUMBER- See Also:
-
COMPLETION_FIELD_NUMBER
public static final int COMPLETION_FIELD_NUMBER- See Also:
-
STATE_FIELD_NUMBER
public static final int STATE_FIELD_NUMBER- See Also:
-
COMMANDS_FIELD_NUMBER
public static final int COMMANDS_FIELD_NUMBER- See Also:
-
REQUEST_STATISTICS_FIELD_NUMBER
public static final int REQUEST_STATISTICS_FIELD_NUMBER- See Also:
-
UPDATES_FIELD_NUMBER
public static final int UPDATES_FIELD_NUMBER- See Also:
-
SYNCHRONIZER_ID_FIELD_NUMBER
public static final int SYNCHRONIZER_ID_FIELD_NUMBER- See Also:
-
TIMINGS_FIELD_NUMBER
public static final int TIMINGS_FIELD_NUMBER- See Also:
-
-
Method Details
-
newInstance
- Overrides:
newInstancein classcom.google.protobuf.GeneratedMessageV3
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor() -
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable internalGetFieldAccessorTable()- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessageV3
-
hasStarted
public boolean hasStarted()Time at which the command was received for interpretation by the participant. Required
.google.protobuf.Timestamp started = 1;- Specified by:
hasStartedin interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder- Returns:
- Whether the started field is set.
-
getStarted
public com.google.protobuf.Timestamp getStarted()Time at which the command was received for interpretation by the participant. Required
.google.protobuf.Timestamp started = 1;- Specified by:
getStartedin interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder- Returns:
- The started.
-
getStartedOrBuilder
public com.google.protobuf.TimestampOrBuilder getStartedOrBuilder()Time at which the command was received for interpretation by the participant. Required
.google.protobuf.Timestamp started = 1;- Specified by:
getStartedOrBuilderin interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder
-
hasCompleted
public boolean hasCompleted()Time at which the command was completed. Optional
.google.protobuf.Timestamp completed = 2;- Specified by:
hasCompletedin interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder- Returns:
- Whether the completed field is set.
-
getCompleted
public com.google.protobuf.Timestamp getCompleted()Time at which the command was completed. Optional
.google.protobuf.Timestamp completed = 2;- Specified by:
getCompletedin interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder- Returns:
- The completed.
-
getCompletedOrBuilder
public com.google.protobuf.TimestampOrBuilder getCompletedOrBuilder()Time at which the command was completed. Optional
.google.protobuf.Timestamp completed = 2;- Specified by:
getCompletedOrBuilderin interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder
-
hasCompletion
public boolean hasCompletion()The completion associated with the command Contains only default values if the command is still pending Optional
.com.daml.ledger.api.v2.Completion completion = 3;- Specified by:
hasCompletionin interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder- Returns:
- Whether the completion field is set.
-
getCompletion
The completion associated with the command Contains only default values if the command is still pending Optional
.com.daml.ledger.api.v2.Completion completion = 3;- Specified by:
getCompletionin interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder- Returns:
- The completion.
-
getCompletionOrBuilder
The completion associated with the command Contains only default values if the command is still pending Optional
.com.daml.ledger.api.v2.Completion completion = 3;- Specified by:
getCompletionOrBuilderin interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder
-
getStateValue
public int getStateValue()The state of the command Required
.com.daml.ledger.api.v2.admin.CommandState state = 4;- Specified by:
getStateValuein interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder- Returns:
- The enum numeric value on the wire for state.
-
getState
The state of the command Required
.com.daml.ledger.api.v2.admin.CommandState state = 4;- Specified by:
getStatein interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder- Returns:
- The state.
-
getCommandsList
The individual submitted commands Required: must be non-empty
repeated .com.daml.ledger.api.v2.Command commands = 5;- Specified by:
getCommandsListin interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder
-
getCommandsOrBuilderList
The individual submitted commands Required: must be non-empty
repeated .com.daml.ledger.api.v2.Command commands = 5;- Specified by:
getCommandsOrBuilderListin interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder
-
getCommandsCount
public int getCommandsCount()The individual submitted commands Required: must be non-empty
repeated .com.daml.ledger.api.v2.Command commands = 5;- Specified by:
getCommandsCountin interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder
-
getCommands
The individual submitted commands Required: must be non-empty
repeated .com.daml.ledger.api.v2.Command commands = 5;- Specified by:
getCommandsin interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder
-
getCommandsOrBuilder
The individual submitted commands Required: must be non-empty
repeated .com.daml.ledger.api.v2.Command commands = 5;- Specified by:
getCommandsOrBuilderin interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder
-
hasRequestStatistics
public boolean hasRequestStatistics()Statistics about the command request Optional
.com.daml.ledger.api.v2.admin.RequestStatistics request_statistics = 6;- Specified by:
hasRequestStatisticsin interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder- Returns:
- Whether the requestStatistics field is set.
-
getRequestStatistics
Statistics about the command request Optional
.com.daml.ledger.api.v2.admin.RequestStatistics request_statistics = 6;- Specified by:
getRequestStatisticsin interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder- Returns:
- The requestStatistics.
-
getRequestStatisticsOrBuilder
public CommandInspectionServiceOuterClass.RequestStatisticsOrBuilder getRequestStatisticsOrBuilder()Statistics about the command request Optional
.com.daml.ledger.api.v2.admin.RequestStatistics request_statistics = 6;- Specified by:
getRequestStatisticsOrBuilderin interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder
-
hasUpdates
public boolean hasUpdates()The ledger updates effected by the command Optional
.com.daml.ledger.api.v2.admin.CommandUpdates updates = 7;- Specified by:
hasUpdatesin interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder- Returns:
- Whether the updates field is set.
-
getUpdates
The ledger updates effected by the command Optional
.com.daml.ledger.api.v2.admin.CommandUpdates updates = 7;- Specified by:
getUpdatesin interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder- Returns:
- The updates.
-
getUpdatesOrBuilder
The ledger updates effected by the command Optional
.com.daml.ledger.api.v2.admin.CommandUpdates updates = 7;- Specified by:
getUpdatesOrBuilderin interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder
-
getSynchronizerId
Synchronizer-ID. May be optional if the transaction was not yet routed. Optional
string synchronizer_id = 8;- Specified by:
getSynchronizerIdin interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder- Returns:
- The synchronizerId.
-
getSynchronizerIdBytes
public com.google.protobuf.ByteString getSynchronizerIdBytes()Synchronizer-ID. May be optional if the transaction was not yet routed. Optional
string synchronizer_id = 8;- Specified by:
getSynchronizerIdBytesin interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder- Returns:
- The bytes for synchronizerId.
-
getTimingsList
Timings for the individual stages Optional: can be empty
repeated .com.daml.ledger.api.v2.admin.Timing timings = 9;- Specified by:
getTimingsListin interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder
-
getTimingsOrBuilderList
Timings for the individual stages Optional: can be empty
repeated .com.daml.ledger.api.v2.admin.Timing timings = 9;- Specified by:
getTimingsOrBuilderListin interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder
-
getTimingsCount
public int getTimingsCount()Timings for the individual stages Optional: can be empty
repeated .com.daml.ledger.api.v2.admin.Timing timings = 9;- Specified by:
getTimingsCountin interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder
-
getTimings
Timings for the individual stages Optional: can be empty
repeated .com.daml.ledger.api.v2.admin.Timing timings = 9;- Specified by:
getTimingsin interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder
-
getTimingsOrBuilder
Timings for the individual stages Optional: can be empty
repeated .com.daml.ledger.api.v2.admin.Timing timings = 9;- Specified by:
getTimingsOrBuilderin interfaceCommandInspectionServiceOuterClass.CommandStatusOrBuilder
-
isInitialized
public final boolean isInitialized()- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessageV3
-
writeTo
- Specified by:
writeToin interfacecom.google.protobuf.MessageLite- Overrides:
writeToin classcom.google.protobuf.GeneratedMessageV3- Throws:
IOException
-
getSerializedSize
public int getSerializedSize()- Specified by:
getSerializedSizein interfacecom.google.protobuf.MessageLite- Overrides:
getSerializedSizein classcom.google.protobuf.GeneratedMessageV3
-
equals
- Specified by:
equalsin interfacecom.google.protobuf.Message- Overrides:
equalsin classcom.google.protobuf.AbstractMessage
-
hashCode
public int hashCode()- Specified by:
hashCodein interfacecom.google.protobuf.Message- Overrides:
hashCodein classcom.google.protobuf.AbstractMessage
-
parseFrom
public static CommandInspectionServiceOuterClass.CommandStatus parseFrom(ByteBuffer data) throws com.google.protobuf.InvalidProtocolBufferException - Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static CommandInspectionServiceOuterClass.CommandStatus parseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException - Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static CommandInspectionServiceOuterClass.CommandStatus parseFrom(com.google.protobuf.ByteString data) throws com.google.protobuf.InvalidProtocolBufferException - Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static CommandInspectionServiceOuterClass.CommandStatus parseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException - Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static CommandInspectionServiceOuterClass.CommandStatus parseFrom(byte[] data) throws com.google.protobuf.InvalidProtocolBufferException - Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static CommandInspectionServiceOuterClass.CommandStatus parseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException - Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static CommandInspectionServiceOuterClass.CommandStatus parseFrom(InputStream input) throws IOException - Throws:
IOException
-
parseFrom
public static CommandInspectionServiceOuterClass.CommandStatus parseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException - Throws:
IOException
-
parseDelimitedFrom
public static CommandInspectionServiceOuterClass.CommandStatus parseDelimitedFrom(InputStream input) throws IOException - Throws:
IOException
-
parseDelimitedFrom
public static CommandInspectionServiceOuterClass.CommandStatus parseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException - Throws:
IOException
-
parseFrom
public static CommandInspectionServiceOuterClass.CommandStatus parseFrom(com.google.protobuf.CodedInputStream input) throws IOException - Throws:
IOException
-
parseFrom
public static CommandInspectionServiceOuterClass.CommandStatus parseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException - Throws:
IOException
-
newBuilderForType
- Specified by:
newBuilderForTypein interfacecom.google.protobuf.Message- Specified by:
newBuilderForTypein interfacecom.google.protobuf.MessageLite
-
newBuilder
-
newBuilder
public static CommandInspectionServiceOuterClass.CommandStatus.Builder newBuilder(CommandInspectionServiceOuterClass.CommandStatus prototype) -
toBuilder
- Specified by:
toBuilderin interfacecom.google.protobuf.Message- Specified by:
toBuilderin interfacecom.google.protobuf.MessageLite
-
newBuilderForType
protected CommandInspectionServiceOuterClass.CommandStatus.Builder newBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent) - Specified by:
newBuilderForTypein classcom.google.protobuf.GeneratedMessageV3
-
getDefaultInstance
-
parser
-
getParserForType
public com.google.protobuf.Parser<CommandInspectionServiceOuterClass.CommandStatus> getParserForType()- Specified by:
getParserForTypein interfacecom.google.protobuf.Message- Specified by:
getParserForTypein interfacecom.google.protobuf.MessageLite- Overrides:
getParserForTypein classcom.google.protobuf.GeneratedMessageV3
-
getDefaultInstanceForType
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-