Uses of Interface
com.daml.ledger.javaapi.data.Event
Packages that use Event
-
Uses of Event in com.daml.ledger.javaapi.data
Classes in com.daml.ledger.javaapi.data that implement EventModifier and TypeClassDescriptionfinal classfinal classfinal classMethods in com.daml.ledger.javaapi.data that return EventModifier and TypeMethodDescriptionstatic EventEvent.fromProtoEvent(com.daml.ledger.api.v2.EventOuterClass.Event event) Methods in com.daml.ledger.javaapi.data that return types with arguments of type EventModifier and TypeMethodDescriptionTransaction.getEvents()Transaction.getEventsById()Returns the events of the transaction by their (node) id.Method parameters in com.daml.ledger.javaapi.data with type arguments of type EventModifier and TypeMethodDescription<WrappedEvent>
Transaction.WrappedTransactionTree<WrappedEvent>Transaction.toWrappedTree(BiFunction<Event, List<WrappedEvent>, WrappedEvent> createWrappedEvent) Constructs a tree described by the transaction.Constructor parameters in com.daml.ledger.javaapi.data with type arguments of type EventModifierConstructorDescriptionTransaction(@NonNull String updateId, @NonNull String commandId, @NonNull String workflowId, @NonNull Instant effectiveAt, @NonNull List<@NonNull Event> events, @NonNull Long offset, @NonNull String synchronizerId, @NonNull com.daml.ledger.api.v2.TraceContextOuterClass.TraceContext traceContext, @NonNull Instant recordTime, @NonNull com.google.protobuf.ByteString externalTransactionHash)