Enum Class UnknownTrailingFieldPolicy

java.lang.Object
java.lang.Enum<UnknownTrailingFieldPolicy>
com.daml.ledger.javaapi.data.codegen.UnknownTrailingFieldPolicy
All Implemented Interfaces:
Serializable, Comparable<UnknownTrailingFieldPolicy>, Constable

public enum UnknownTrailingFieldPolicy extends Enum<UnknownTrailingFieldPolicy>
Policy for handling unknown trailing fields when decoding a Daml record into a Java Class by codegen
  • Enum Constant Details

  • Method Details

    • values

      public static UnknownTrailingFieldPolicy[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static UnknownTrailingFieldPolicy valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null