Uses of Package
com.daml.ledger.javaapi.data
Packages that use com.daml.ledger.javaapi.data
Package
Description
-
Classes in com.daml.ledger.javaapi.data used by com.daml.ledger.javaapi.dataClassDescriptionThis class can be used to build a valid submission.This interface represents events in
ActiveContracts.This class contains utilities to decode aCreatedEventand create anUpdateFormat, aTransactionFormator aEventFormatby provided parties.This interface represents events inTransactions.Settings for including an interface inCumulativeFilter.This class can be used to build a valid submission.A Timestamp value is represented as microseconds since the UNIX epoch.This interface represents events inTopologyTransactions.A generic class that encapsulates a transaction tree along with a list of the wrapped root events of the tree.This class can be used to build a valid submission for an Update.A Ledger event regarding a workflow identified by theWorkflowEvent.getWorkflowId(). -
Classes in com.daml.ledger.javaapi.data used by com.daml.ledger.javaapi.data.codegenClassDescription
-
Classes in com.daml.ledger.javaapi.data used by com.daml.ledger.javaapi.data.codegen.json