All Classes and Interfaces
Class
Description
Parent of all generated
ByKey classes within templates and interfaces.Parent of all generated
ByKey classes within interfaces.This represents a Daml choice that can be exercised on
ContractIds of type
ContractId<Tpl>.This class can be used to build a valid submission.
A superclass for all codegen-generated Contracts.
Metadata and utilities associated with a template as a whole, rather than one single contract
made from that template.
This interface represents events in
ActiveContracts.This class contains utilities to decode a
CreatedEvent and create an
UpdateFormat, a TransactionFormat or a EventFormat by provided
parties.This class is used as a super class for all concrete ContractIds generated by the java codegen
with the following properties:
The commonality between
ContractCompanion and InterfaceCompanion.A superclass for all codegen-generated Contracts whose templates have a
key defined.Parent of all generated
CreateAnd classes within templates and interfaces.Parent of all generated
CreateAnd classes within interfaces.This class contains information related to a result after a contract is created.
Base interface of all decoded-to-codegen Daml enums.
Base class of all decoded-to-codegen Daml records with no type parameters.
The codegen-decoded form of any of these:
what
DamlRecord describes,
a Variant without type parameters, or
any DamlEnum.This interface represents events in
Transactions.This class contains information related to the result after a choice is exercised.
Root of all generated
Exercises interfaces for templates and Daml interfaces.Adds
Exercises.Archivable.exerciseArchive() to every exercise target.Settings for including an interface in
CumulativeFilter.This is an interface describing classes that contains or can generate a list of
CommandMetadata and utilities associated with an interface as a whole.
ValueDecoders for Daml types that are not code-generated.This class can be used to build a valid submission.
A Timestamp value is represented as microseconds since the UNIX epoch.
This interface represents events in
TopologyTransactions.A generic class that encapsulates a transaction tree along with a list of the wrapped root
events of the tree.
This class can be used to build a valid submission for an Update.
A converter from the encoded form of a Daml value, represented by
Value, to the
codegen-decoded form, represented by Data.Base class of all decoded-to-codegen Daml variants with no type parameters.
A Ledger event regarding a workflow identified by the
WorkflowEvent.getWorkflowId().