All Classes Interface Summary Class Summary Enum Summary Exception Summary
| Class |
Description |
| ArchivedEvent |
|
| Bool |
|
| ByKey |
Parent of all generated ByKey classes within templates and interfaces.
|
| ByKey.ToInterface |
Parent of all generated ByKey classes within interfaces.
|
| Checkpoint |
|
| Command |
|
| CompletionEndResponse |
|
| CompletionStreamRequest |
|
| CompletionStreamResponse |
|
| Contract<Id,Data> |
A superclass for all codegen-generated Contracts.
|
| Contract |
|
| ContractCompanion<Ct,Id,Data> |
Metadata and utilities associated with a template as a whole, rather than one single contract
made from that template.
|
| ContractCompanion.WithKey<Ct,Id,Data,Key> |
|
| ContractCompanion.WithKey.NewContract<Ct,Id,Data,Key> |
|
| ContractCompanion.WithoutKey<Ct,Id,Data> |
|
| ContractCompanion.WithoutKey.NewContract<Ct,Id,Data> |
|
| ContractId<T> |
This class is used as a super class for all concrete ContractIds generated by the java codegen
with the following properties:
|
| ContractId |
|
| ContractTypeCompanion |
|
| ContractWithKey<Id,Data,Key> |
|
| CreateAnd |
Parent of all generated CreateAnd classes within templates and interfaces.
|
| CreateAnd.ToInterface |
Parent of all generated CreateAnd classes within interfaces.
|
| CreateAndExerciseCommand |
|
| CreateCommand |
|
| CreatedEvent |
|
| CreateUserRequest |
|
| CreateUserResponse |
|
| DamlCollectors |
|
| DamlEnum |
|
| DamlGenMap |
|
| DamlList |
|
| DamlMap |
Deprecated.
|
| DamlOptional |
|
| DamlRecord |
|
| DamlRecord.Field |
|
| DamlTextMap |
|
| Date |
|
| Decimal |
Deprecated.
|
| DeleteUserRequest |
|
| DeleteUserResponse |
|
| Event |
|
| ExerciseByKeyCommand |
|
| ExerciseCommand |
|
| ExercisedEvent |
|
| Exercises<Cmd> |
Root of all generated Exercises interfaces for templates and Daml interfaces.
|
| Filter |
|
| FiltersByParty |
|
| GetActiveContractsRequest |
|
| GetActiveContractsResponse |
|
| GetFlatTransactionResponse |
|
| GetLedgerEndResponse |
|
| GetPackageResponse |
|
| GetPackageResponse.HashFunction |
|
| GetPackageStatusResponse |
|
| GetPackageStatusResponse.PackageStatus |
|
| GetTransactionResponse |
|
| GetTransactionsRequest |
|
| GetTransactionsResponse |
|
| GetTransactionTreesResponse |
|
| GetUserRequest |
|
| GetUserResponse |
|
| GrantUserRightsRequest |
|
| GrantUserRightsResponse |
|
| Identifier |
|
| InclusiveFilter |
|
| Int64 |
|
| InterfaceCompanion<I> |
Metadata and utilities associated with an interface as a whole.
|
| LedgerOffset |
|
| LedgerOffset.Absolute |
|
| LedgerOffset.LedgerBegin |
|
| LedgerOffset.LedgerEnd |
|
| ListUserRightsRequest |
|
| ListUserRightsResponse |
|
| ListUsersResponse |
|
| NoFilter |
|
| Numeric |
|
| Party |
|
| Record |
Deprecated.
|
| Record.Field |
Deprecated.
|
| RevokeUserRightsRequest |
|
| RevokeUserRightsResponse |
|
| SubmitAndWaitRequest |
|
| SubmitCommandsRequest |
|
| SubmitRequest |
|
| Template |
|
| Text |
|
| Timestamp |
A Timestamp value is represented as microseconds since the UNIX epoch.
|
| Transaction |
|
| TransactionFilter |
|
| TransactionTree |
|
| TreeEvent |
|
| Unit |
|
| UnsupportedEventTypeException |
|
| User |
|
| User.Right |
|
| User.Right.CanActAs |
|
| User.Right.CanReadAs |
|
| User.Right.ParticipantAdmin |
|
| Value |
|
| Variant |
|
| WorkflowEvent |
|