Package com.daml.ledger.api.v2
Class CommandsOuterClass.PrefetchContractKey
java.lang.Object
com.google.protobuf.AbstractMessageLite
com.google.protobuf.AbstractMessage
com.google.protobuf.GeneratedMessageV3
com.daml.ledger.api.v2.CommandsOuterClass.PrefetchContractKey
- All Implemented Interfaces:
CommandsOuterClass.PrefetchContractKeyOrBuilder,com.google.protobuf.Message,com.google.protobuf.MessageLite,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,Serializable
- Enclosing class:
CommandsOuterClass
public static final class CommandsOuterClass.PrefetchContractKey
extends com.google.protobuf.GeneratedMessageV3
implements CommandsOuterClass.PrefetchContractKeyOrBuilder
Preload contractsProtobuf type
com.daml.ledger.api.v2.PrefetchContractKey- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic final classPreload contractsNested classes/interfaces inherited from class com.google.protobuf.GeneratedMessageV3
com.google.protobuf.GeneratedMessageV3.BuilderParent, com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>,BuilderT extends com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageT, BuilderT>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessageOrBuilder<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessageV3.FieldAccessorTable, com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter Nested classes/interfaces inherited from class com.google.protobuf.AbstractMessageLite
com.google.protobuf.AbstractMessageLite.InternalOneOfEnum -
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final intstatic final intstatic final intFields inherited from class com.google.protobuf.GeneratedMessageV3
alwaysUseFieldBuilders, unknownFieldsFields inherited from class com.google.protobuf.AbstractMessage
memoizedSizeFields inherited from class com.google.protobuf.AbstractMessageLite
memoizedHashCode -
Method Summary
Modifier and TypeMethodDescriptionbooleancom.daml.ledger.api.v2.ValueOuterClass.ValueThe key of the contract the client wants to prefetch.com.daml.ledger.api.v2.ValueOuterClass.ValueOrBuilderThe key of the contract the client wants to prefetch.static final com.google.protobuf.Descriptors.DescriptorintgetLimit()The number of contracts to prefetch for this key, if available.com.google.protobuf.Parser<CommandsOuterClass.PrefetchContractKey> intcom.daml.ledger.api.v2.ValueOuterClass.IdentifierThe template of contract the client wants to prefetch.com.daml.ledger.api.v2.ValueOuterClass.IdentifierOrBuilderThe template of contract the client wants to prefetch.booleanThe key of the contract the client wants to prefetch.inthashCode()booleanhasLimit()The number of contracts to prefetch for this key, if available.booleanThe template of contract the client wants to prefetch.protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTablefinal booleannewBuilder(CommandsOuterClass.PrefetchContractKey prototype) newBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent) protected ObjectnewInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused) parseDelimitedFrom(InputStream input) parseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) parseFrom(byte[] data) parseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) parseFrom(com.google.protobuf.ByteString data) parseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) parseFrom(com.google.protobuf.CodedInputStream input) parseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) parseFrom(InputStream input) parseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) parseFrom(ByteBuffer data) parseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) static com.google.protobuf.Parser<CommandsOuterClass.PrefetchContractKey> parser()voidwriteTo(com.google.protobuf.CodedOutputStream output) Methods inherited from class com.google.protobuf.GeneratedMessageV3
canUseUnsafe, computeStringSize, computeStringSizeNoTag, emptyBooleanList, emptyDoubleList, emptyFloatList, emptyIntList, emptyList, emptyLongList, getAllFields, getDescriptorForType, getField, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, getUnknownFields, hasField, hasOneof, internalGetMapField, internalGetMapFieldReflection, isStringEmpty, makeExtensionsImmutable, makeMutableCopy, makeMutableCopy, mergeFromAndMakeImmutableInternal, mutableCopy, mutableCopy, mutableCopy, mutableCopy, mutableCopy, newBooleanList, newBuilderForType, newDoubleList, newFloatList, newIntList, newLongList, parseDelimitedWithIOException, parseDelimitedWithIOException, parseUnknownField, parseUnknownFieldProto3, parseWithIOException, parseWithIOException, parseWithIOException, parseWithIOException, serializeBooleanMapTo, serializeIntegerMapTo, serializeLongMapTo, serializeStringMapTo, writeReplace, writeString, writeStringNoTagMethods inherited from class com.google.protobuf.AbstractMessage
findInitializationErrors, getInitializationErrorString, hashBoolean, hashEnum, hashEnumList, hashFields, hashLong, toStringMethods inherited from class com.google.protobuf.AbstractMessageLite
addAll, addAll, checkByteStringIsUtf8, toByteArray, toByteString, writeDelimitedTo, writeToMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface com.google.protobuf.MessageLite
toByteArray, toByteString, writeDelimitedTo, writeToMethods inherited from interface com.google.protobuf.MessageOrBuilder
findInitializationErrors, getAllFields, getDescriptorForType, getField, getInitializationErrorString, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, getUnknownFields, hasField, hasOneof
-
Field Details
-
TEMPLATE_ID_FIELD_NUMBER
public static final int TEMPLATE_ID_FIELD_NUMBER- See Also:
-
CONTRACT_KEY_FIELD_NUMBER
public static final int CONTRACT_KEY_FIELD_NUMBER- See Also:
-
LIMIT_FIELD_NUMBER
public static final int LIMIT_FIELD_NUMBER- See Also:
-
-
Method Details
-
newInstance
- Overrides:
newInstancein classcom.google.protobuf.GeneratedMessageV3
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor() -
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable internalGetFieldAccessorTable()- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessageV3
-
hasTemplateId
public boolean hasTemplateId()The template of contract the client wants to prefetch. Both package-name and package-id reference identifier formats for the template-id are supported. Note: The package-id reference identifier format is deprecated. We plan to end support for this format in version 3.4. Required
.com.daml.ledger.api.v2.Identifier template_id = 1;- Specified by:
hasTemplateIdin interfaceCommandsOuterClass.PrefetchContractKeyOrBuilder- Returns:
- Whether the templateId field is set.
-
getTemplateId
public com.daml.ledger.api.v2.ValueOuterClass.Identifier getTemplateId()The template of contract the client wants to prefetch. Both package-name and package-id reference identifier formats for the template-id are supported. Note: The package-id reference identifier format is deprecated. We plan to end support for this format in version 3.4. Required
.com.daml.ledger.api.v2.Identifier template_id = 1;- Specified by:
getTemplateIdin interfaceCommandsOuterClass.PrefetchContractKeyOrBuilder- Returns:
- The templateId.
-
getTemplateIdOrBuilder
public com.daml.ledger.api.v2.ValueOuterClass.IdentifierOrBuilder getTemplateIdOrBuilder()The template of contract the client wants to prefetch. Both package-name and package-id reference identifier formats for the template-id are supported. Note: The package-id reference identifier format is deprecated. We plan to end support for this format in version 3.4. Required
.com.daml.ledger.api.v2.Identifier template_id = 1;- Specified by:
getTemplateIdOrBuilderin interfaceCommandsOuterClass.PrefetchContractKeyOrBuilder
-
hasContractKey
public boolean hasContractKey()The key of the contract the client wants to prefetch. Required
.com.daml.ledger.api.v2.Value contract_key = 2;- Specified by:
hasContractKeyin interfaceCommandsOuterClass.PrefetchContractKeyOrBuilder- Returns:
- Whether the contractKey field is set.
-
getContractKey
public com.daml.ledger.api.v2.ValueOuterClass.Value getContractKey()The key of the contract the client wants to prefetch. Required
.com.daml.ledger.api.v2.Value contract_key = 2;- Specified by:
getContractKeyin interfaceCommandsOuterClass.PrefetchContractKeyOrBuilder- Returns:
- The contractKey.
-
getContractKeyOrBuilder
public com.daml.ledger.api.v2.ValueOuterClass.ValueOrBuilder getContractKeyOrBuilder()The key of the contract the client wants to prefetch. Required
.com.daml.ledger.api.v2.Value contract_key = 2;- Specified by:
getContractKeyOrBuilderin interfaceCommandsOuterClass.PrefetchContractKeyOrBuilder
-
hasLimit
public boolean hasLimit()The number of contracts to prefetch for this key, if available. This is in addition to disclosed contracts. - for backward compatibility reason, absence is interpreted as 1 - 0 is forbidden - capped at 2^31 - 1. The system may impose further limits. Optional
optional uint32 limit = 3;- Specified by:
hasLimitin interfaceCommandsOuterClass.PrefetchContractKeyOrBuilder- Returns:
- Whether the limit field is set.
-
getLimit
public int getLimit()The number of contracts to prefetch for this key, if available. This is in addition to disclosed contracts. - for backward compatibility reason, absence is interpreted as 1 - 0 is forbidden - capped at 2^31 - 1. The system may impose further limits. Optional
optional uint32 limit = 3;- Specified by:
getLimitin interfaceCommandsOuterClass.PrefetchContractKeyOrBuilder- Returns:
- The limit.
-
isInitialized
public final boolean isInitialized()- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessageV3
-
writeTo
- Specified by:
writeToin interfacecom.google.protobuf.MessageLite- Overrides:
writeToin classcom.google.protobuf.GeneratedMessageV3- Throws:
IOException
-
getSerializedSize
public int getSerializedSize()- Specified by:
getSerializedSizein interfacecom.google.protobuf.MessageLite- Overrides:
getSerializedSizein classcom.google.protobuf.GeneratedMessageV3
-
equals
- Specified by:
equalsin interfacecom.google.protobuf.Message- Overrides:
equalsin classcom.google.protobuf.AbstractMessage
-
hashCode
public int hashCode()- Specified by:
hashCodein interfacecom.google.protobuf.Message- Overrides:
hashCodein classcom.google.protobuf.AbstractMessage
-
parseFrom
public static CommandsOuterClass.PrefetchContractKey parseFrom(ByteBuffer data) throws com.google.protobuf.InvalidProtocolBufferException - Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static CommandsOuterClass.PrefetchContractKey parseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException - Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static CommandsOuterClass.PrefetchContractKey parseFrom(com.google.protobuf.ByteString data) throws com.google.protobuf.InvalidProtocolBufferException - Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static CommandsOuterClass.PrefetchContractKey parseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException - Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static CommandsOuterClass.PrefetchContractKey parseFrom(byte[] data) throws com.google.protobuf.InvalidProtocolBufferException - Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static CommandsOuterClass.PrefetchContractKey parseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException - Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static CommandsOuterClass.PrefetchContractKey parseFrom(InputStream input) throws IOException - Throws:
IOException
-
parseFrom
public static CommandsOuterClass.PrefetchContractKey parseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException - Throws:
IOException
-
parseDelimitedFrom
public static CommandsOuterClass.PrefetchContractKey parseDelimitedFrom(InputStream input) throws IOException - Throws:
IOException
-
parseDelimitedFrom
public static CommandsOuterClass.PrefetchContractKey parseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException - Throws:
IOException
-
parseFrom
public static CommandsOuterClass.PrefetchContractKey parseFrom(com.google.protobuf.CodedInputStream input) throws IOException - Throws:
IOException
-
parseFrom
public static CommandsOuterClass.PrefetchContractKey parseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException - Throws:
IOException
-
newBuilderForType
- Specified by:
newBuilderForTypein interfacecom.google.protobuf.Message- Specified by:
newBuilderForTypein interfacecom.google.protobuf.MessageLite
-
newBuilder
-
newBuilder
public static CommandsOuterClass.PrefetchContractKey.Builder newBuilder(CommandsOuterClass.PrefetchContractKey prototype) -
toBuilder
- Specified by:
toBuilderin interfacecom.google.protobuf.Message- Specified by:
toBuilderin interfacecom.google.protobuf.MessageLite
-
newBuilderForType
protected CommandsOuterClass.PrefetchContractKey.Builder newBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent) - Specified by:
newBuilderForTypein classcom.google.protobuf.GeneratedMessageV3
-
getDefaultInstance
-
parser
-
getParserForType
- Specified by:
getParserForTypein interfacecom.google.protobuf.Message- Specified by:
getParserForTypein interfacecom.google.protobuf.MessageLite- Overrides:
getParserForTypein classcom.google.protobuf.GeneratedMessageV3
-
getDefaultInstanceForType
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-