Package com.daml.ledger.api.v2
Enum Class CryptoOuterClass.CryptoKeyFormat
java.lang.Object
java.lang.Enum<CryptoOuterClass.CryptoKeyFormat>
com.daml.ledger.api.v2.CryptoOuterClass.CryptoKeyFormat
- All Implemented Interfaces:
com.google.protobuf.Internal.EnumLite,com.google.protobuf.ProtocolMessageEnum,Serializable,Comparable<CryptoOuterClass.CryptoKeyFormat>,Constable
- Enclosing class:
CryptoOuterClass
public static enum CryptoOuterClass.CryptoKeyFormat
extends Enum<CryptoOuterClass.CryptoKeyFormat>
implements com.google.protobuf.ProtocolMessageEnum
Serialization format for crypto keys and signaturesProtobuf enum
com.daml.ledger.api.v2.CryptoKeyFormat-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescriptionASN.1 + DER encoding Legacy format no longer used, except for migrationsASN.1 + DER-encoding of X.509 SubjectPublicKeyInfo structure: https://datatracker.ietf.org/doc/html/rfc5280#section-4.1Raw encoding of a keyCRYPTO_KEY_FORMAT_UNSPECIFIED = 0; -
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final intASN.1 + DER encoding Legacy format no longer used, except for migrationsstatic final intASN.1 + DER-encoding of X.509 SubjectPublicKeyInfo structure: https://datatracker.ietf.org/doc/html/rfc5280#section-4.1static final intRaw encoding of a keystatic final intCRYPTO_KEY_FORMAT_UNSPECIFIED = 0; -
Method Summary
Modifier and TypeMethodDescriptionforNumber(int value) static final com.google.protobuf.Descriptors.EnumDescriptorfinal com.google.protobuf.Descriptors.EnumDescriptorfinal intfinal com.google.protobuf.Descriptors.EnumValueDescriptorstatic com.google.protobuf.Internal.EnumLiteMap<CryptoOuterClass.CryptoKeyFormat> valueOf(int value) Deprecated.valueOf(com.google.protobuf.Descriptors.EnumValueDescriptor desc) Returns the enum constant of this class with the specified name.Returns the enum constant of this class with the specified name.static CryptoOuterClass.CryptoKeyFormat[]values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
CRYPTO_KEY_FORMAT_UNSPECIFIED
CRYPTO_KEY_FORMAT_UNSPECIFIED = 0; -
CRYPTO_KEY_FORMAT_DER
ASN.1 + DER encoding Legacy format no longer used, except for migrations
CRYPTO_KEY_FORMAT_DER = 1; -
CRYPTO_KEY_FORMAT_RAW
Raw encoding of a key
CRYPTO_KEY_FORMAT_RAW = 2; -
CRYPTO_KEY_FORMAT_DER_X509_SUBJECT_PUBLIC_KEY_INFO
public static final CryptoOuterClass.CryptoKeyFormat CRYPTO_KEY_FORMAT_DER_X509_SUBJECT_PUBLIC_KEY_INFOASN.1 + DER-encoding of X.509 SubjectPublicKeyInfo structure: https://datatracker.ietf.org/doc/html/rfc5280#section-4.1
CRYPTO_KEY_FORMAT_DER_X509_SUBJECT_PUBLIC_KEY_INFO = 3; -
UNRECOGNIZED
-
-
Field Details
-
CRYPTO_KEY_FORMAT_UNSPECIFIED_VALUE
public static final int CRYPTO_KEY_FORMAT_UNSPECIFIED_VALUECRYPTO_KEY_FORMAT_UNSPECIFIED = 0;- See Also:
-
CRYPTO_KEY_FORMAT_DER_VALUE
public static final int CRYPTO_KEY_FORMAT_DER_VALUEASN.1 + DER encoding Legacy format no longer used, except for migrations
CRYPTO_KEY_FORMAT_DER = 1;- See Also:
-
CRYPTO_KEY_FORMAT_RAW_VALUE
public static final int CRYPTO_KEY_FORMAT_RAW_VALUERaw encoding of a key
CRYPTO_KEY_FORMAT_RAW = 2;- See Also:
-
CRYPTO_KEY_FORMAT_DER_X509_SUBJECT_PUBLIC_KEY_INFO_VALUE
public static final int CRYPTO_KEY_FORMAT_DER_X509_SUBJECT_PUBLIC_KEY_INFO_VALUEASN.1 + DER-encoding of X.509 SubjectPublicKeyInfo structure: https://datatracker.ietf.org/doc/html/rfc5280#section-4.1
CRYPTO_KEY_FORMAT_DER_X509_SUBJECT_PUBLIC_KEY_INFO = 3;- See Also:
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
getNumber
public final int getNumber()- Specified by:
getNumberin interfacecom.google.protobuf.Internal.EnumLite- Specified by:
getNumberin interfacecom.google.protobuf.ProtocolMessageEnum
-
valueOf
Deprecated.Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
value- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
forNumber
- Parameters:
value- The numeric wire value of the corresponding enum entry.- Returns:
- The enum associated with the given numeric wire value.
-
internalGetValueMap
public static com.google.protobuf.Internal.EnumLiteMap<CryptoOuterClass.CryptoKeyFormat> internalGetValueMap() -
getValueDescriptor
public final com.google.protobuf.Descriptors.EnumValueDescriptor getValueDescriptor()- Specified by:
getValueDescriptorin interfacecom.google.protobuf.ProtocolMessageEnum
-
getDescriptorForType
public final com.google.protobuf.Descriptors.EnumDescriptor getDescriptorForType()- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.ProtocolMessageEnum
-
getDescriptor
public static final com.google.protobuf.Descriptors.EnumDescriptor getDescriptor() -
valueOf
public static CryptoOuterClass.CryptoKeyFormat valueOf(com.google.protobuf.Descriptors.EnumValueDescriptor desc) Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
desc- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-